# set working directory here
#setwd('~/Dropbox/graphs_practical_advice_new/kastellec_graphs_advice_replication')
setwd('')


rm(list=ls(all=TRUE))

#Read in required libraries
library(tidyverse)
library(tools)
library(magrittr)
library(gridExtra)
library(haven)
library(ggprism)
library(ggpattern)
library(readstata13)

#GRAPHING SHORTCUTS used in many of the graphs below
title.size <- 20
x.axis.tick.size <- 14
y.axis.tick.size <- 14
x.axis.label.size <- 18
y.axis.label.size <- 18
facet.text <- 15

##########################################
# Figure 1 from figures in Hankinson and Magazinnik (2022)
##########################################
# note this code uses functions a variety of functions to generate the figure. While more complicated than is necessary 
#for producing a single graph, I have maintained the structure of the original code for the sake of comparability.
#You can search for ****here to see where the new graph is created below.

# load data 
regset <- read.csv("Hankinson/housing_agg.csv")

# define subgroups: segregation
seg_ave <- tapply(regset$H_citytract_NHW[regset$switcher2==1 & regset$treat==0], 
                  as.character(regset$location[regset$switcher2==1 & regset$treat==0]), 
                  mean, na.rm = TRUE)
seg_high_third <- names(seg_ave)[seg_ave > quantile(seg_ave, probs = .67, na.rm = TRUE)]
seg_low_third <- names(seg_ave)[seg_ave < quantile(seg_ave, probs = .33, na.rm = TRUE)]
regset$seg.high.third <- ifelse(regset$location %in% seg_high_third, 1, 0) 
regset$seg.low.third <- ifelse(regset$location %in% seg_low_third, 1, 0) 

# define subgroups: majority population size   
regset$pct_max <- ifelse(regset$max.group=="asian", regset$pct_asian, 
                         ifelse(regset$max.group=="white", regset$pct_wnh,
                                ifelse(regset$max.group=="hisp", regset$pct_hisp,
                                       regset$pct_black)))

max_ave <- tapply(regset$pct_max[regset$switcher2==1 & regset$treat==0],  
                  as.character(regset$location[regset$switcher2==1 & regset$treat==0]), 
                  mean, na.rm = TRUE)
max_high_third <- names(max_ave)[max_ave > quantile(max_ave, probs = .67, na.rm = TRUE)]
max_low_third <- names(max_ave)[max_ave < quantile(max_ave, probs = .33, na.rm = TRUE)]
regset$max.high.third <- ifelse(regset$location %in% max_high_third, 1, 0)   
regset$max.low.third <- ifelse(regset$location %in% max_low_third, 1, 0)  

# define subgroups: majority's political power
regset$maj_elect <- (ifelse(regset$max.group=="asian", regset$prop_asian_elected_past12/regset$pct_asian, 
                            ifelse(regset$max.group=="white", regset$prop_white_elected_past12/regset$pct_wnh,
                                   ifelse(regset$max.group=="hisp", regset$prop_latino_elected_past12/regset$pct_hisp,
                                          regset$prop_black_elected_past12/regset$pct_black)))) * 100 

maj_elect_ave <- regset$maj_elect[regset$switcher2==1 & !is.na(regset$year_switch) & regset$year==(regset$year_switch - 1)]
names(maj_elect_ave) <- regset$location[regset$switcher2==1 & !is.na(regset$year_switch) & regset$year==(regset$year_switch - 1)]
maj_elect_high_third <- names(maj_elect_ave)[maj_elect_ave > quantile(maj_elect_ave, probs = .67, na.rm = TRUE)]
maj_elect_low_third <- names(maj_elect_ave)[maj_elect_ave < quantile(maj_elect_ave, probs = .33, na.rm = TRUE)]
regset$maj_elect.high.third <- ifelse(regset$location %in% maj_elect_high_third, 1, 0)   
regset$maj_elect.low.third <- ifelse(regset$location %in% maj_elect_low_third, 1, 0)  

####################################################
# prepare data 
####################################################
# remove observations with missing values 
df <- na.omit(regset[,c("switcher", "l.total", "l.single", "l.multi", "treat", "location", "year", "H_citytract_NHW",
                        "population.th", "pct_wnh", "pct_black", "pct_hisp", "own_rate", "vacancy_rate", "prop_min_elected_past12",
                        "med_value.th", "med_income.th", "switcher2", "max.low.third", "max.high.third", "seg.low.third", 
                        "seg.high.third", "maj_elect.high.third", "maj_elect.low.third", "year_switch")])

# sort data by city and year 
df <- df[order(df$location, df$year),]

####################################################
# define functions
####################################################
# construct treatment and control sets 
construct.sets <- function(df, pre.years, post.years) {
  treat.set <- NULL
  control.set <- NULL
  treats <- unique(df$location[df$treat==1])
  for (i in c(1:length(treats))) {
    # treatment set 
    treat.year <- unique(df$year_switch[df$location==treats[i]])
    treat.set.i <- df[df$location==treats[i] & df$year %in% c((treat.year - pre.years):(treat.year + post.years)),]
    treat.set.i$t <- treat.set.i$year - treat.year
    treat.set <- rbind(treat.set, treat.set.i)
    # control set 
    control.set.i <- df[df$year_switch>=(treat.year + post.years + 1) & df$year %in% c((treat.year - pre.years):(treat.year + post.years)),]
    control.set.i$t <- control.set.i$year - treat.year
    control.set <- rbind(control.set, control.set.i)
  }
  return(list(treat.set = treat.set, control.set = control.set))
}

# functions for plots 
trendplot1 <- function(byvar, treat.set, control.set, labels, ylab, ylim = NULL) {
  t <- data.frame(y = treat.set[,byvar], x = treat.set$t) 
  t$t <- "t"
  
  c <- data.frame(y = control.set[,byvar], x = control.set$t) 
  c$t <- "c"
  
  # put them together
  toplot <- rbind(t, c)
  
  # plot
  toplot$t <- factor(toplot$t, levels = c("c", "t"))
  toplot$x <- as.numeric(as.character(toplot$x))
  alpha <- ifelse(toplot$t=="c", .1, .5)
  
  # compute ylim
  if (is.null(ylim)) {
    ylim <- c(0,(max(toplot$y) + .02))
  }  
  
  g <- ggplot(data = toplot, aes(x = x, y = y, colour = t, group = t)) + 
    geom_vline(xintercept = 0, linetype = "dashed") + 
    stat_summary(fun.data = mean_cl_boot, geom = "pointrange", position = position_dodge(width = .3)) + 
    stat_summary(fun.data = mean_cl_boot, geom = "line", position = position_dodge(width = .3)) + 
    xlab("Years to first district election") + 
    ylab(ylab) + 
    theme_minimal() + 
    theme(legend.position = "bottom") + 
    labs(color = "") +
    scale_color_manual(labels = labels, values = c("c" = "gray60", "t" = "gray30")) +
    coord_cartesian(ylim = ylim) 
  print(g)
}

####################################################
# generate new version of  original plot
####################################################
out <- construct.sets(df[df$switcher2==1,], pre.years = 3, post.years = 3)

pdf("Hankinson/hankinson_figure_1_original_in_R.pdf", height=6, width=8)

trendplot1(byvar = "l.multi", 
           treat.set = out$treat.set, 
           control.set = out$control.set, 
           labels = c("Control", "Treated"),
           ylab = "Logged multifamily units permitted",
           ylim = c(0, 4.5))

dev.off()

########################################################################################################
#Revised version
########################################################################################################

# generate plots 
trendplot1 <- function(byvar, treat.set, control.set, labels, ylab, ylim = NULL) {
  t <- data.frame(y = treat.set[,byvar], x = treat.set$t) 
  t$t <- "t"
  
  c <- data.frame(y = control.set[,byvar], x = control.set$t) 
  c$t <- "c"
  
  # put them together
  toplot <- rbind(t, c)
  
  # plot
  toplot$t <- factor(toplot$t, levels = c("c", "t"))
  toplot$x <- as.numeric(as.character(toplot$x))
  alpha <- ifelse(toplot$t=="c", .1, .5)
  
  # compute ylim
  if (is.null(ylim)) {
    ylim <- c(0,(max(toplot$y) + .02))
  }  
 
  #****here is where graph is actually generated; see comments to explain what is changed, relative to original 
  g <- ggplot(data = toplot, aes(x = x, y = y, color = t, group = t, linetype=t, shape=t, fill=t)) + 
    geom_vline(xintercept = 0, linetype = 6, lwd=1) + #use dot-dash to distinguish from CI lines
    stat_summary(fun.data = mean_cl_boot, geom = "line", position = position_dodge(width = .3), size=1.2) + 
    stat_summary(fun.data = mean_cl_boot, geom = "pointrange", position = position_dodge(width = .3), stroke=2) + 
    xlab("Years to first district election") + 
    ylab(ylab) + 
    theme_bw() + 
    theme(axis.text.x = element_text(size=18), axis.title.x=element_text(size=20), #increase label sizes
          axis.text.y = element_text(size=18), axis.title.y = element_text(size=20),#increase label sizes
          legend.position="none",
          panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(),  #suppress vertical grid lines
          plot.margin = unit(c(.5, .1, .1, .1), "cm"),) + #adjust margins to create more whitespace above top axis
    coord_cartesian(ylim = c(0,4)) + #set limits of y-axis
    scale_x_continuous(breaks=seq(-3,3,1)) + scale_y_continuous(breaks=seq(0,4,1), expand = c(0, 0)) +
    labs(color = "") +
    scale_color_manual(labels = labels, values = c("c" = "blue", "t" = "orange")) +
    scale_shape_manual(values = c(2,1)) +
    scale_fill_manual(values = c("white", "white")) + 
    annotate("text", x = 1.5, y =3.3, label ="Treated", color="orange", cex=6)+ 
    annotate("text", x = 1.3, y =1.9, label ="Control", color="blue", cex=6) 
  print(g)
}

out <- construct.sets(df[df$switcher2==1,], pre.years = 3, post.years = 3)

pdf("Hankinson/hankinson_figure_1_new.pdf", height=6, width=8)

trendplot1(byvar = "l.multi", 
           treat.set = out$treat.set, 
           control.set = out$control.set, 
           labels = c("Control", "Treated"),
           ylab = "Logged multifamily units permitted",
           ylim = c(0, 4.5))


dev.off()

####################################################################################################################################################################################
####GRUMBACH, Figure 3
####################################################################################################################################################################################
plotdata <- readRDS("Grumbach/grumbach_Rdata_for_figure.rds")

#original
pdf("Grumbach/grumbach_Figure_03_original.pdf", h=4, w=8)

ggplot(plotdata[!is.na(plotdata$State),], aes(x=year, y=democracy_mcmc, size=State, color=State, 
                                              linetype=State)) +
  geom_ribbon(aes(ymin=democracy_mcmc-democracy_mcmc_sd,
                  ymax=democracy_mcmc+democracy_mcmc_sd), alpha = .3, color=NA) +
  geom_line(aes(group=state)) +
  scale_linetype_manual(values=c(1,2,3,1)) +
  scale_color_manual(values=c("black","black", "black","grey80")) +
  scale_size_manual(values=c(1.2, 1.2, 1.2, 0.2), guide=F) +
   xlab("Year") +   ylab("Democracy Score") +
  theme_bw() 

dev.off()

#revised
  #add objects for colors
nc <- "orange"
wash <- "blue"
texas <- "dark green"
other <- "gray80"

pdf("Grumbach/grumbach_Figure_03_revised.pdf", height=4, w=8)

ggplot(plotdata[!is.na(plotdata$State),], aes(x=year, y=democracy_mcmc, size=State, color=State, 
                                              linetype=State)) +
  geom_ribbon(aes(ymin=democracy_mcmc-democracy_mcmc_sd,
                  ymax=democracy_mcmc+democracy_mcmc_sd), alpha = .3, color=NA) +
  geom_line(aes(group=state)) +
  scale_linetype_manual(values=c(1,2,3,1)) +
  scale_color_manual(values=c(nc, texas, wash, other)) +
  scale_size_manual(values=c(1.2, 1.2, 1.2, 0.2), guide=F) +
  xlab("") +   ylab("Democracy Score") + theme_bw() +
  scale_x_continuous(guide = "prism_minor", 
                     limits = c(2000, 2018),
                     expand = c(0, 0),
                     minor_breaks = seq(2000,2020, 1)) +
  scale_y_continuous(breaks=c(-2,0,2)) + 
  theme(axis.text.x = element_text(size=18), axis.title.x=element_blank(), 
        axis.text.y = element_text(size=18), axis.title.y = element_text(size=20),
        legend.position="none",
        panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(),  #suppress vertical grid lines
        #plot.margin = unit(c(.1, .1, .1, .1), "cm"),#adjust margins to create more whitespace above top axis+
        prism.ticks.length.x = unit(5, "pt"),
        panel.grid.major.y = element_blank(), panel.grid.minor.y = element_blank()) + #suppress horizontal grid lines)
#add labels for lines
annotate("text", x =2015.5, y = -3.7, label ="North Carolina",cex=5.2,adj=1, color=nc, angle=-10) +
annotate("text", x =2015, y = 2.3, label ="Washington",cex=5.2,adj=1, color=wash) +
annotate("text", x =2017, y = -.4, label ="Texas",cex=5.2,adj=1, color=texas)+
annotate("text", x =2003, y = -2.2, label ="other states",cex=5,adj=1, color="gray50")
  
dev.off()


############################################################
############################################################
#APSR editors' notes
############################################################
############################################################
  #recreate figure 3a and 3b
  #note: i have not matched the color of the lines
apsr.a <- read.csv('APSR_data/113_2_EdNotes_figure3a.csv')

ggplot(apsr.a, aes(year, duration_review_days, linetype=section, color=section)) + theme_bw() + 
  geom_line()+ #add grepel for line labels at end 
  scale_x_continuous(limits=c(2008,2018), breaks=c(2008:2018), labels=c(2008:2018)) +
  ylab("days") +
  theme(axis.text.x = element_text(size=14, angle=45, hjust=1), axis.title.x=element_blank(), 
        axis.text.y = element_text(size=18), axis.title.y = element_text(size=20),
       # legend.position="none"
        )
  
apsr.b <- read.csv('APSR_data/113_2_EdNotes_figure3b.csv')

ggplot(apsr.b, aes(year, review_word_count, linetype=section, color=section)) + theme_bw() + 
  geom_line()+ #add grepel for line labels at end 
  scale_x_continuous(limits=c(2008,2018), breaks=c(2008:2018), labels=c(2008:2018)) +
  ylab("tokens") +
  theme(axis.text.x = element_text(size=14, angle=45, hjust=1), axis.title.x=element_blank(), 
        axis.text.y = element_text(size=18), axis.title.y = element_text(size=20),
        # legend.position="none"
  )


####
#Now using facets
#first pool data to enable easier sorting of factors
apsr <- left_join(apsr.a,apsr.b)
head(apsr)
apsr <- apsr %>% 
  pivot_longer( cols=c(duration_review_days, review_word_count))
head(apsr)

#calculate mean--here use duration --days by group for ordering
apsr.means <- subset(apsr, name=="duration_review_days") %>% group_by(section) %>% summarise (
  mean.days= mean(value))

apsr.combined <-  left_join(apsr,apsr.means) %>% 
  dplyr::arrange(mean.days)
head(apsr.combined)

#reorder section factor by increasing number of overall mean days for review
apsr.combined$section  <- factor( apsr.combined $section, 
                            levels=unique( apsr.combined $section[order(apsr.combined $mean.days, decreasing=TRUE)]), ordered=TRUE)

apsr.combined$section 

#now do separate facet plots
apsr.a <- subset(apsr.combined , name=="duration_review_days")

a.plot <- 

ggplot(apsr.a, aes(year, value)) + theme_bw() + 
  facet_wrap(~section, ncol=2) +  geom_line() +
  ylab("Average days per review") +
  scale_x_continuous(guide = "prism_minor", 
                     limits = c(2008, 2018),
                     breaks=c(2010,2015),
                     expand = c(0, 0),
                     minor_breaks = seq(2008,2018, 1)) +
  theme(axis.text.x = element_text(size=16), axis.title.x=element_blank(), 
        axis.text.y = element_text(size=16), axis.title.y = element_text(size=16),
        prism.ticks.length.x = unit(5, "pt"),#adjust length of minor tick marks
        legend.position="none",#suppress legend,
        strip.text.x = element_text(color="dark green", size=14), #change color and size of facet strip text
        panel.spacing = unit(1, "lines"), #add more space between panels to better fit axis tick labels
        plot.margin = unit(c(.5, .5, .1, .1), "cm"),#adjust spacing between panels
        panel.grid.minor.y = element_blank()  #suppress horizontal grid lines)
  )

apsr.b <- subset(apsr.combined, name=="review_word_count")

b.plot <- ggplot(apsr.b, aes(year, value)) + theme_bw() + 
  facet_wrap(~section, ncol=2) +  geom_line() +
  ylab("Average number of words per review") +
  scale_x_continuous(guide = "prism_minor", 
                     limits = c(2008, 2018),
                     breaks=c(2010,2015),
                     expand = c(0, 0),
                     minor_breaks = seq(2008,2018, 1)) +
  theme(axis.text.x = element_text(size=16), axis.title.x=element_blank(), 
        axis.text.y = element_text(size=16), axis.title.y = element_text(size=16),
        prism.ticks.length.x = unit(5, "pt"),#adjust length of minor tick marks
        legend.position="none",#suppress legend,
        strip.text.x = element_text(color="dark green", size=14), #change color and size of facet strip text
        panel.spacing = unit(.5, "lines"), #add more space between panels to better fit axis tick labels
        plot.margin = unit(c(.5, .5, .1, .1), "cm"),#adjust spacing between panels
        panel.grid.minor.y = element_blank()  #suppress horizontal grid lines)
  )

# #combined into single PDF
pdf("APSR_data/apsr_combined_new.pdf", height=10, width=13)

grid.arrange(a.plot , b.plot, nrow=1)

dev.off()


########################################################################
# HERTEL-FERNANDEZ, MATTO MILDENBERGER, and LEAH C. STOKES  , Legislative Staff and Representation in Congress, #figure 2
########################################################################
hms <- read.csv('Hertel_Fernandez/hertel_fernandez_data.csv')
hms$category <- factor(hms$category)
levels(hms$category)

levels(hms$category) <- c("Businesses", "CBO", "Communication from constituents","Concerns about primary opponents",
                          "CRS",  "GAO", "Party Leaders",   "Public opinion of constituents", 
                          "Public opinion of country", "Concerns about re-election",  "Think tanks", "Unions")
hms$category <- factor(  hms$category, #reorder category by mean levels
                              levels=unique(hms$category[order(hms$mean_dem_rep)]))

levels(hms$category)

hms$category 
hms.long <- gather( subset(hms, select = -mean_dem_rep), party, value, -category)#reshape to long, dropping mean_dem_rep
hms.long$party[hms.long$party=="rep"] <- "1_rep"#hack to put republicans 1st in plot

pdf("Hertel_Fernandez/hertel_reproduce_ggplot.pdf", height=10, width=12)

ggplot(hms.long, aes(y = value, x= category, fill = party, linetype=party)) +   theme_bw() +
  ylab("% staffers reporting item as important condition") + xlab("") +
  geom_bar(stat="identity", width=.5, position = "dodge") + coord_flip() +
  scale_fill_manual(values=c("red", "blue")) + 
 # scale_fill_grey(start = 0, end = .9) +
  theme(legend.position="none",#suppress legend
        axis.text.x = element_text(size=x.axis.tick.size), axis.title.x = element_text(size=x.axis.label.size),
        axis.text.y = element_text(size=y.axis.tick.size), axis.title.y = element_text(size=y.axis.label.size)) +
  annotate("text", x =8.2, y = 28, label ="Democrats",cex=5.2,adj=0, color="blue") +
  annotate("text", x =7.9, y = 60, label ="Republicans",cex=5.2,adj=0, color="red") 

dev.off()

##adding grid lines
  #code taken from https://stackoverflow.com/questions/67164758/adding-hatches-or-patterns-to-ggplot-bars

pdf("Hertel_Fernandez/hertel_new_ggplot.pdf", height=10, width=12)

ggplot(hms.long, aes(y = value, x= category, fill = party)) + theme_bw()+
  geom_col_pattern(
    aes(pattern = party),
    colour = "black",
    pattern_fill = "black",
    pattern_angle = 45,
    pattern_density = 0.1,
    pattern_spacing = 0.05,
    position = position_dodge2(preserve = 'single'),
  ) +
  scale_pattern_manual(
    values = c("stripe", "none"),
    guide = guide_legend(override.aes = list(fill = "grey70")) # <- make lighter
  ) +
  # scale_fill_discrete(
  #   guide = guide_legend(override.aes = list(pattern = "none")) # <- hide pattern
  # ) +
  coord_flip()+
  scale_fill_manual(values=c("red", "blue"))+
  theme(legend.position="none",#suppress legend
        axis.text.x = element_text(size=18), axis.title.x = element_text(size=x.axis.label.size),
        axis.text.y = element_text(size=18), axis.title.y = element_text(size=y.axis.label.size)) +
  labs(x="", y="% staffers reporting item as important consideration")+
  annotate("text", x =8.2, y = 29, label ="Democrats",cex=6,adj=0, color="blue") +
  annotate("text", x =7.75, y = 61, label ="Republicans",cex=6, adj=0, color="red") 

dev.off()

############################################################
#BOSTON AND SILVERIA, FIGURE 1
############################################################
boston <- read.dta13("Boston_Silveira/boston_silveira_data_for_figure1.dta")

boston.keep <- subset(boston, !is.na(norm_sent) & active=="A") %>% 
  mutate(
    electorate=factor(electorate)
  )

pdf("Boston_Silveira/boston_new.pdf", height=6, width=8)

set.seed(12323)
ggplot(boston.keep, aes(cens_sent, linetype=electorate, color=electorate)) + theme_bw()+
    stat_ecdf(geom = "step", pad=FALSE, aes(linetype=electorate, color=electorate), size=1.5) +
  scale_color_manual(values=c("red", "blue")) +
  scale_x_continuous(limits = c(0,1), breaks=seq(0,1,.2), labels=c(0, ".2",".4", ".6", ".8", 1), expand=c(.01,0)) +
  scale_y_continuous(limits = c(0,1), breaks=seq(.2,1,.2), labels=c(".2",".4", ".6", ".8", 1 ), expand=c(.01,0)) +
  coord_cartesian(xlim=c(0,1), ylim=c(0,1)) + 
  labs(x="Normalized minimum sentence", y="Cumulatitive distribution") +
  theme(aspect.ratio=1, #make plot "square" since axes are same dimensions
    plot.title = element_text(size =18, face = "bold"),  
        axis.text.x = element_text(size=18, angle=0),
        axis.text.y = element_text(size=18),
        axis.title.x = element_text(size=y.axis.label.size),
        axis.title.y = element_text(size=y.axis.label.size) , 
        legend.position="none") + #suppress legend)
  annotate("text", x =.46, y = .35, label ="Conservative\ndistricts", cex=5,angle=20, color="red") +
  annotate("text", x =.37, y = .44, label ="Liberal districts", cex=5,angle=20, color="blue")

dev.off()



